Multicolumn: Use a variable as a factor to give rows in a table.

MulticolumnR Documentation

Use a variable as a factor to give rows in a table.

Description

Use a variable as a factor to give rows in a table.

Usage

Multicolumn(
  x,
  name = deparse(expr),
  levelnames = levels(x),
  width = 2,
  first = 1,
  justify = "l",
  texify = getOption("tables.texify", FALSE),
  expr = substitute(x),
  override = TRUE
)

modelsummary documentation built on Feb. 13, 2026, 5:10 p.m.