Percent: Pseudo-function to compute a statistic relative to a...

PercentR Documentation

Pseudo-function to compute a statistic relative to a reference set.

Description

Pseudo-function to compute a statistic relative to a reference set.

Usage

Percent(denom = "all", fn = percent)

modelsummary documentation built on Feb. 13, 2026, 5:10 p.m.