The `gt::as_latex` function is still in development, rather feature poor, and prone to breakage. This function is a stopgap measure which adds a little functionality and "cleans-up" some of the LaTeX output to avoid common compilation errors. In time, as upstream improves, the goal is to deprecate this function.
clean_latex(
tab,
label = NULL,
latex_env = "longtable",
gof_regex = "^Num Obs."
)table object produced by `modelsummary` or `gt`
string will be inserted as a `label`
the default LaTeX environment is longtable. Fix this argument to 'table' if you want to use a tabular nested inside a table.
regex which identifies the first GOF statistic. Used to figure out where to insert a midrule to separate coefficients from GOFs.
a string object with LaTeX code